@@ -61,12 +61,15 @@
 
  * And utility functions:
 
+   and()                                       -- Logical "and" function
    CDFNormal(z)                                -- Integral of the normal at z
    CalcCumulative(n, x[], p[], Cdf[], o)       -- Constructs a CDF given a PDF
    erfc(x)                                     -- Complementary error function
+   leq()                                       -- Logical lower or equal function
    lnDFNormal(x, mu, sd)                       -- Log of the normal density
    lnGamma(x)                                  -- Natural log of gamma function
    lnDFBeta(x, alpha, beta, min, max)          -- Log of beta density
+   piecewise(...)                              -- Piecewise function
    SetSeed(seed)                               -- Sets the seed of Randoms
    InitRandom(seed, f)                         -- Initializes the package
 
@@ -1023,7 +1026,6 @@ double UniformRandom (double a, double b)
      2 4
        5 etc.
 */
-
 void WishartRandom (long n, long p, double *t, double *w, double *work)
 {
   double eta, sum;
@@ -1094,7 +1096,6 @@ void WishartRandom (long n, long p, double *t, double *w, double *work)
    Supports piecewise-constant (order 0) and piecewise-linear
    (order 1) pdfs.
 */
-
 void CalcCumulative (long cDim, double *rg_x, double *rg_pdf,
                      double *rg_Cdf, int  iOrder)
 {
@@ -1136,7 +1137,6 @@ void CalcCumulative (long cDim, double *rg_x, double *rg_pdf,
 
    the probability for [-inf;Z] under the normal distribution
 */
-
 double CDFNormal (double z)
 {
   register double tmp;
@@ -1184,7 +1184,6 @@ double erfc (double x)
 
    Do a linear interpolation to return x
 */
-
 double InterpolateX (double rgX[], double rgY[], long lLower, double dY)
 {
   return rgX[lLower] + (dY - rgY[lLower]) *
@@ -1227,7 +1226,6 @@ double lnDFBeta (double x, double alpha, double beta, double min, double max)
    the log of the normal density function
    0.9189385332046 is log(sqrt(2*PI))
 */
-
 double lnDFNormal (double x, double mu, double sd)
 {
   if (sd <= 0.0) {
@@ -1247,7 +1245,6 @@ double lnDFNormal (double x, double mu, double sd)
    Press et al. 
    It can be used to compute factorials since ln(n!) = lnGamma(n + 1)
 */
-
 double lnGamma (double x)
 {
   double dSeries, dTemp;
@@ -1272,12 +1269,51 @@ double lnGamma (double x)
 } /* lnGamma */
 
 
+/* ----------------------------------------------------------------------------
+   Boolean "AND" logical function.
+
+   Return TRUE if both its two arguments are TRUE. This is just for 
+   compatibility with SBML.
+*/
+BOOL and (BOOL A, BOOL B)
+{ return (A && B); } /* piecewise */
+
+#ifdef ndef
+/* ----------------------------------------------------------------------------
+   Piecewise math function.
+
+   Takes an unknwn number of pairs of (double, boolean), and eventually a 
+   terminal double. Returns the first double value for which the associated 
+   condition is true. If none is true it returns FALSE or the terminal double
+   if one is given.
+   Example: {double am = 1., pm = 2., noon = 3., time = 55.888;
+             return piecewise (am, (time < 12), pm, (time > 12), noon);}
+*/
+void piecewise (double X1 ...)
+{
+  va_list argptr;
+
+  va_start(argprt, X1);
+
+  if ((arg1 = va_arg (argptr, char*)) != NULL) {
+    test = arg1;
+    while ((arg[++nargs] = va_arg(ap, char*)) != NULL) {};
+  }
+  va_end (ap);
+
+  /* get a target - clause pair
+    szMsg1 = va_arg(ap, PSTR);
+    szMsg2 = va_arg(ap, PSTR); */
+  va_end(ap);
+
+} /* piecewise */
+#endif
+
 /* ----------------------------------------------------------------------------
    PiecewiseRandom
                                                   __
    returns a variate that is distributed along a /  \ shaped distribution.
 */
-
 double PiecewiseRandom (double min, double a, double b, double max)
 {
   double dTemp;
