@@ -725,12 +725,13 @@ BOOL GetPrintStep (PINPUTBUF pibIn, PSTR szLex, POUTSPEC pos)
   PPRINTREC pprintrec[MAX_PRINT_VARS];
   BOOL      bErr = FALSE, bOK = TRUE;
   HVAR      hvar = 0;
-  int       nVars = 0, n, iLex, iType;
+  int       nVars = 0, n, iLex;
   long      i;
   double    dStart = 0, dEnd = 0, dStep = 0, dTmp;
 
   // get the opening parenthesis and list of variables to print
-  if (bErr = EGetPunct (pibIn, szLex, CH_LPAREN))
+  bErr = EGetPunct (pibIn, szLex, CH_LPAREN);
+  if (bErr)
     goto Exit_GetPrintStep;
 
   for (;;) {
